@@ -1,4 +1,6 @@
 import click
+import click_log
+import logging
 
 from gex.commands.archive.archive import archive
 from gex.commands.file.file import file
@@ -6,6 +8,9 @@ from gex.commands.finder.finder import finder
 from gex.commands.postprocess.postprocess import postprocess
 from gex.commands.version import version
 
+logger = logging.getLogger('gextoolbox')
+click_log.basic_config(logger)
+
 @click.group()
 def cli():
     pass
